try:
    from . import _reader
except ImportError as e:
    from . import _reader_py as _reader

from ._reader_common import HEADER_SCHEMA, SYNC_SIZE, MAGIC
from ._reader_common import SchemaResolutionError

acquaint_schema = _reader.acquaint_schema
reader = iter_avro = _reader.iter_avro
schemaless_reader = _reader.schemaless_reader
read_data = _reader.read_data
is_avro = _reader.is_avro

READERS = _reader.READERS
LOGICAL_READERS = _reader.LOGICAL_READERS

__all__ = [
    'acquaint_schema', 'reader', 'schemaless_reader', 'read_data', 'is_avro',
    'HEADER_SCHEMA', 'SYNC_SIZE', 'MAGIC', 'SchemaResolutionError',
    'LOGICAL_READERS', 'READERS',
]



try:
    from . import _writer
except ImportError as e:
    from . import _writer_py as _writer

from ._writer_common import SCHEMA_DEFS

acquaint_schema = _writer.acquaint_schema
writer = _writer.writer
schemaless_writer = _writer.schemaless_writer
write_data = _writer.write_data

WRITERS = _writer.WRITERS
LOGICAL_WRITERS = _writer.LOGICAL_WRITERS

__all__ = [
    'SCHEMA_DEFS', 'acquaint_schema', 'writer', 'schemaless_writer',
    'write_data', 'WRITERS', 'LOGICAL_WRITERS',
]
